#!/bin/bash

# Script authored by FM Ytreberg <fmytreberg@gmail.com>
# Last modified Jan 2015
#
# For usage information run with '-h' flag.
#
# Required: pdb2pqr binary http://sourceforge.net/projects/pdb2pqr/
pdb2pqr="/home/marty/apps/pdb2pqr-2.0.0/pdb2pqr"
if [ ! -z `hostname | grep compute` ] || [ ! -z `hostname | grep coan` ]; then
    pdb2pqr="/share/apps/pdb2pqr-2.0.0/pdb2pqr"
fi


show_help() {
cat << EOF
usage: ${0##*/} [options]

Converts a PDB files into a PQR file.
    
optional arguments:
  -h          display this help and exit
  -i PATTERN  (required) pattern of input PDB file(s) to convert
  -o OUTBASE  (default=pqr) prefix for output PQR file(s)
  -s          (default=false) change residue names to standard, e.g., HID->HIS
  -c          (default=false) use charmm naming instead of amber
EOF
}

#
# PARSE COMMAND LINE
#

input="NONE"
output="pqr"
standard=false
charmm=false
while getopts ":hi:o:sc" opt; do
    case $opt in
        h)
            show_help
            exit
            ;;
        i)
            input=$OPTARG
            ;;
        o)
            output=$OPTARG
            ;;
        s)
            standard=true
            ;;
        c)
            charmm=true
            ;;
        \?)
            echo "error: invalid option: -$OPTARG"
            exit
            ;;
    esac
done
if [ "$OPTIND" -eq 1 ]; then  # Show help if no arguments are specified.
    show_help
    exit
elif [ "$input" == "NONE" ]; then
    echo "error: -i flag required"
    exit
fi

if [ "$charmm" == true ]; then
    options="--with-ph=7.0 --ff=charmm --ffout=charmm --chain --verbose"
else
    options="--with-ph=7.0 --ff=amber --ffout=amber --chain --verbose"
fi

# Append to log file
log="pdb2pqr.log"
echo "** Running $0 $@ **" >> $log
echo >> $log

#
# MAIN PROGRAM
#

pdb=(`find * -maxdepth 1 -name "${input}*.pdb"`)
if [ "${#pdb[@]}" -eq 0 ]; then
    echo "error: no ${input}*.pdb files found"
    exit
fi
nout=0
for ipdb in "${pdb[@]}"; do
    opdb="${output}.${ipdb}"
    $pdb2pqr $options $ipdb $opdb >> $log 2>&1
    if [ "$standard" == true ]; then
        sed -i 's/HID/HIS/g;s/HIE/HIS/g;s/HIP/HIS/g;s/ISU/CYS/g;s/CYX/CYS/g'\
                $opdb
    else
        sed -i 's/ISU/CYS/g' $opdb
    fi
    if [ -e $opdb ]; then
	    ((nout=nout+1))
	    echo " $ipdb sucessfully converted"
    else
	    echo "error: there was a problem converting structure $ipdb"
    fi
done

echo "script complete: $nout pdb file(s) successfully converted"
